Class: Aws::IoTSecureTunneling::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTSecureTunneling::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotsecuretunneling/client.rb
Overview
An API client for IoTSecureTunneling. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTSecureTunneling::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#close_tunnel(params = {}) ⇒ Struct
Closes a tunnel identified by the unique tunnel id.
-
#describe_tunnel(params = {}) ⇒ Types::DescribeTunnelResponse
Gets information about a tunnel identified by the unique tunnel id.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#list_tunnels(params = {}) ⇒ Types::ListTunnelsResponse
List all tunnels for an Amazon Web Services account.
-
#open_tunnel(params = {}) ⇒ Types::OpenTunnelResponse
Creates a new tunnel, and returns two client access tokens for clients to use to connect to the IoT Secure Tunneling proxy server.
-
#rotate_tunnel_access_token(params = {}) ⇒ Types::RotateTunnelAccessTokenResponse
Revokes the current client access token (CAT) and returns new CAT for clients to use when reconnecting to secure tunneling to access the same tunnel.
-
#tag_resource(params = {}) ⇒ Struct
A resource tag.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
483 484 485 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 483 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
853 854 855 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 853 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
856 857 858 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 856 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 826 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTSecureTunneling') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotsecuretunneling' context[:gem_version] = '1.56.0' Seahorse::Client::Request.new(handlers, context) end |
#close_tunnel(params = {}) ⇒ Struct
Closes a tunnel identified by the unique tunnel id. When a ‘CloseTunnel` request is received, we close the WebSocket connections between the client and proxy server so no data can be transmitted.
Requires permission to access the [CloseTunnel] action.
517 518 519 520 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 517 def close_tunnel(params = {}, = {}) req = build_request(:close_tunnel, params) req.send_request() end |
#describe_tunnel(params = {}) ⇒ Types::DescribeTunnelResponse
Gets information about a tunnel identified by the unique tunnel id.
Requires permission to access the [DescribeTunnel] action.
565 566 567 568 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 565 def describe_tunnel(params = {}, = {}) req = build_request(:describe_tunnel, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
593 594 595 596 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 593 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_tunnels(params = {}) ⇒ Types::ListTunnelsResponse
List all tunnels for an Amazon Web Services account. Tunnels are listed by creation time in descending order, newer tunnels will be listed before older tunnels.
Requires permission to access the [ListTunnels] action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
646 647 648 649 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 646 def list_tunnels(params = {}, = {}) req = build_request(:list_tunnels, params) req.send_request() end |
#open_tunnel(params = {}) ⇒ Types::OpenTunnelResponse
Creates a new tunnel, and returns two client access tokens for clients to use to connect to the IoT Secure Tunneling proxy server.
Requires permission to access the [OpenTunnel] action.
707 708 709 710 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 707 def open_tunnel(params = {}, = {}) req = build_request(:open_tunnel, params) req.send_request() end |
#rotate_tunnel_access_token(params = {}) ⇒ Types::RotateTunnelAccessTokenResponse
Revokes the current client access token (CAT) and returns new CAT for clients to use when reconnecting to secure tunneling to access the same tunnel.
Requires permission to access the [RotateTunnelAccessToken] action.
<note markdown=“1”> Rotating the CAT doesn’t extend the tunnel duration. For example, say the tunnel duration is 12 hours and the tunnel has already been open for 4 hours. When you rotate the access tokens, the new tokens that are generated can only be used for the remaining 8 hours.
</note>
764 765 766 767 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 764 def rotate_tunnel_access_token(params = {}, = {}) req = build_request(:rotate_tunnel_access_token, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
A resource tag.
793 794 795 796 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 793 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource.
817 818 819 820 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 817 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
846 847 848 |
# File 'lib/aws-sdk-iotsecuretunneling/client.rb', line 846 def waiter_names [] end |