Class: Aws::IoTSecureTunneling::Types::RotateTunnelAccessTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTSecureTunneling::Types::RotateTunnelAccessTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotsecuretunneling/types.rb
Overview
Note:
When making an API call, you may pass RotateTunnelAccessTokenRequest data as a hash:
{
tunnel_id: "TunnelId", # required
client_mode: "SOURCE", # required, accepts SOURCE, DESTINATION, ALL
destination_config: {
thing_name: "ThingName",
services: ["Service"], # required
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_mode ⇒ String
The mode of the client that will use the client token, which can be either the source or destination, or both source and destination.
-
#destination_config ⇒ Types::DestinationConfig
The destination configuration.
-
#tunnel_id ⇒ String
The tunnel for which you want to rotate the access tokens.
Instance Attribute Details
#client_mode ⇒ String
The mode of the client that will use the client token, which can be either the source or destination, or both source and destination.
308 309 310 311 312 313 314 |
# File 'lib/aws-sdk-iotsecuretunneling/types.rb', line 308 class RotateTunnelAccessTokenRequest < Struct.new( :tunnel_id, :client_mode, :destination_config) SENSITIVE = [] include Aws::Structure end |
#destination_config ⇒ Types::DestinationConfig
The destination configuration.
308 309 310 311 312 313 314 |
# File 'lib/aws-sdk-iotsecuretunneling/types.rb', line 308 class RotateTunnelAccessTokenRequest < Struct.new( :tunnel_id, :client_mode, :destination_config) SENSITIVE = [] include Aws::Structure end |
#tunnel_id ⇒ String
The tunnel for which you want to rotate the access tokens.
308 309 310 311 312 313 314 |
# File 'lib/aws-sdk-iotsecuretunneling/types.rb', line 308 class RotateTunnelAccessTokenRequest < Struct.new( :tunnel_id, :client_mode, :destination_config) SENSITIVE = [] include Aws::Structure end |